# Table of Contents

- [password-rules](<./password-rules.md>)
- [SAP LeanIX](<./SAP-LeanIX.md>)
- [Password Rules](<./Password-Rules.md>)
  - [Regular Password Rules](<./Password-Rules/Regular-Password-Rules.md>)
  - [Strict Password Rules](<./Password-Rules/Strict-Password-Rules.md>)
